Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client generates license challenges and verifies server responses.
func NewClient ¶
NewClient creates a Client from three passwords. Each password must be at least 8 characters.
func (*Client) VerifyResponse ¶
VerifyResponse reports whether response is a valid server reply bound to challenge.
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server verifies license challenges and generates bound response tokens.
func NewServer ¶
NewServer creates a Server from three passwords. Each password must be at least 8 characters.
Click to show internal directories.
Click to hide internal directories.